/*
 * Copyright (C) 2014 Víctor Matía Rodríguez.
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; version 3.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

import QtQuick 2.0

import Ubuntu.Components 1.1
import Ubuntu.Components.Popups 1.0

import "components"
import "ui"

import CheetaHCS 0.1

/*!
    \brief MainView with Tabs element.
           First Tab has a single Label and
           second Tab has a single ToolbarAction.
*/

MainView {
    id: root
    // objectName for functional testing purposes (autopilot-qt5)
    objectName: "mainView"

    // Note! applicationName needs to match the "name" field of the click manifest
    applicationName: "com.ubuntu.developer.vitimiti.cheetahcs"

    /*
     This property enables the application to change orientation
     when the device is rotated. The default is false.
    */
    automaticOrientation: true

    // Removes the old toolbar and enables new features of the new header.
    useDeprecatedToolbar: false

    width: units.gu(48)
    height: units.gu(75)

    property real margins: units.gu(2)
    property real spacing: units.gu(1)

    // The configuration dialog for a first start
    ConfigDialogComponent {
        id: configDialog
        objectName: "config_dialog"
    }

    // The backend
    CheetaHCS {
        id: cheetaHCSType
        objectName: "cheetaHCS_type"

        // If the configuration doesn't exist
        onConfigExistsChanged: {
            if (configExists !== true)
                PopupUtils.open(configDialog) // Open the config dialog
        }
    }

    // Make the start checks
    Component.onCompleted: {
        cheetaHCSType.startChecks()
    }

    // The three tabs
    Tabs {
        id: tabs

        // The welcome tab
        WelcomeTab {
            objectName: "welcome_tab"
        }

        // The log in tab
        LogInTab {
            objectName: "logIn_tab"
        }

        // The self add tab
        CheetaHCSTab {
            objectName: "cheetaHCS_tab"
        }
    }
}

