/*
 * Copyright (C) 2014 Víctor Matía Rodríguez.
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; version 3.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

import QtQuick 2.0

import Ubuntu.Components 1.1
import Ubuntu.Components.Pickers 1.0
import Ubuntu.Components.Popups 1.0

import CheetaHCS 0.1

Component {
    id: dialogComponent

    // The dialog for the configuration
    Dialog {
        id: dialog
        objectName: "dialog"

        // The backend component
        CheetaHCS {
            id: cheetaHCSType
            objectName: "cheetaHCS_type"
        }

        title: i18n.tr("Configuration")

        text: i18n.tr("Please, choose your hospital and primary center")

        // The picker for the given hospitals
        Picker {
            id: hospitalPicker
            objectName: "hospitalPicker"

            model: cheetaHCSType.hospitals
            delegate: PickerDelegate {
                Label {
                    fontSize: "x-small"
                    text: modelData
                }
            }
        }

        // The picker for the given primary centers
        Picker {
            id: primaryCenterPicker
            objectName: "primaryCenterPicker"

            model: cheetaHCSType.primaryCenters
            delegate: PickerDelegate {
                Label {
                    fontSize: "x-small"
                    text: modelData
                }
            }
        }

        Button {
            id: okBtn
            objectName: "okBtn"

            text: i18n.tr("OK")
            onClicked: {
                // Configure what's been chosen
                cheetaHCSType.configure(hospitalPicker.selectedIndex,
                                        primaryCenterPicker.selectedIndex)
                // Read such configuration
                cheetaHCSType.readConfig()

                // Close the dialog
                PopupUtils.close(dialog)
            }
        }
    }
}
