/*
 * Copyright (C) 2014 Víctor Matía Rodríguez.
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; version 3.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

import QtQuick 2.0
import QtQuick.Layouts 1.1

import Ubuntu.Components 1.1
import Ubuntu.Components.Popups 1.0
import Ubuntu.Layouts 1.0

import "layouts/loginpage"

Page {
    id: logInPage

    title: i18n.tr("Log In")
    height: parent.height - header.height

    // The help component
    LogInPageHelpComponent {
        id: logInPageHelp
        objectName: "logInPageHelp_component"
    }

    // The actions
    head.actions: [
        // Show the new user page
        Action {
            id: newUserAction
            objectName: "newUserAction"

            text: i18n.tr("New user")
            iconSource: "../graphics/new-user.svg"
            onTriggered: {
                functionalityStack.pop()
                functionalityStack.push(newUserPage)
            }
        },
        // Show the change/forgot password page
        Action {
            id: forgotPassAction
            objectName: "forgotPassAction"

            text: i18n.tr("New password")
            iconSource: "../graphics/password.svg"
            onTriggered: {
                functionalityStack.pop()
                functionalityStack.push(passesPage)
            }
        },
        // Show the help for this page
        Action {
            id: helpAction
            objectName: "helpAction"

            text: i18n.tr("Help")
            iconSource: "../graphics/help.svg"
            onTriggered: PopupUtils.open(logInPageHelp)
        }
    ]

    // The layouts
    Layouts {
        id: logInPageLayout
        objectName: "logInPageLayout"

        width: parent.width
        height: parent.height

        layouts: []

        // The default layout
        BasicLayout {
            objectName: "basic_layout"
        }
    }
}
