/*
 * Copyright (C) 2014 Víctor Matía Rodríguez.
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; version 3.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

import QtQuick 2.0
import QtQuick.Layouts 1.1

import Ubuntu.Components 1.1

Item {
    width: parent.width
    height: parent.height

    // The grid that has the form to log in
    GridLayout {
        id: firstGrid
        objectName: "firstGrid"

        columnSpacing: root.spacing
        rowSpacing: root.spacing
        columns: 2
        rows: 2
        width: parent.width - root.margins * 2
        x: root.margins
        y: parent.height / 2 - height - secondGrid.height -
           root.spacing + root.margins

        Label {
            id: userLbl
            objectName: "userLbl"

            text: i18n.tr("User:")
        }

        TextField {
            id: userField
            objectName: "userField"

            Layout.fillWidth: true
            placeholderText: i18n.tr("My user")
            inputMethodHints: {
                Qt.ImhNoAutoUppercase
                Qt.ImhNoPredictiveText
                Qt.ImhSensitiveData
            }
        }

        Label {
            id: passLbl
            objectName: "passLbl"

            text: i18n.tr("Password:")
        }

        TextField {
            id: passField
            objectName: "passField"

            Layout.fillWidth: true
            placeholderText: i18n.tr("My password")
            echoMode: TextInput.Password
            inputMethodHints: {
                Qt.ImhNoAutoUppercase
                Qt.ImhNoPredictiveText
                Qt.ImhSensitiveData
            }
        }
    }

    // The grid with the functions
    GridLayout {
        id: secondGrid
        objectName: "secondGrid"

        columnSpacing: root.spacing
        rowSpacing: root.spacing
        columns: 2
        rows: 1
        width: parent.width - root.margins * 2
        x: root.margins + parent.width / 2 - logInBtn.width -
           showPassRow.width / 2
        y: firstGrid.y + firstGrid.height +
           root.spacing

        Button {
            id: logInBtn
            objectName: "logInBtn"

            text: i18n.tr("Log In")
            color: UbuntuColors.orange
        }

        Row {
            id: showPassRow
            objectName: "showPassRow"

            spacing: root.spacing

            Layout.alignment: Layout.Right
            Label {
                y: showPassBtn.y + root.spacing

                text: i18n.tr("Show password:")
            }

            // The possibility to show the password, touch like
            CheckBox {
                id: showPassBtn
                objectName: "showPassBtn"

                text: i18n.tr("Show password:")

                onCheckedChanged: {
                    if (checked)
                        passField.echoMode = TextInput.Normal
                    else
                        passField.echoMode = TextInput.Password
                }
            }
        }
    }
}
