/*
 * Copyright (C) 2014 Víctor Matía Rodríguez.
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; version 3.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

import QtQuick 2.0
import QtQuick.Layouts 1.1

import Ubuntu.Components 1.1
import Ubuntu.Components.ListItems 1.0 as ListItem
import Ubuntu.Components.Pickers 1.0
import Ubuntu.Components.Popups 1.0

import "../../"

Item {
    width: parent.width
    height: parent.height

    // In case the fields are not filled
    EmptyFieldsFailComponent {
        id: emptyFields
        objectName: "emptyFields"
    }

    // In case the passwords are not equal
    BadPassesComponent {
        id: badPasses
        objectName: "badPasses"
    }

    // The shape that holds the form for the forgotten password
    UbuntuShape {
        id: firstShape
        objectName: "firstShape"

        x: root.margins
        y: root.margins
        width: parent.width - root.margins * 2
        height: (parent.height - root.margins * 2) / 2

        // The always visible header indicating what it is
        ListItem.Header {
            id: firstShapeHeader
            objectName: "firstShapeHeader"

            text: i18n.tr("I forgot my password")
        }

        // The flickable to be able to see all the fields
        Flickable {
            id: firstShapeFlickable
            objectName: "firstShapeFlickable"

            clip: true
            width: parent.width
            height: parent.height - firstShapeHeader.height
            contentWidth: parent.width
            contentHeight: firstGrid.height + submitBtnOne.height
                           + root.spacing * 3
            x: root.spacing
            y: root.spacing + firstShapeHeader.height

            // The grid that contains the form itself
            GridLayout {
                id: firstGrid
                objectName: "firstGrid"
                columnSpacing: root.spacing
                rowSpacing: root.spacing
                columns: 2
                rows: 5
                width: parent.width - root.spacing * 2

                Label {
                    id: nameLblForgot
                    objectName: "nameLbl"

                    text: i18n.tr("Name:")
                }

                TextField {
                    id: nameFieldForgot
                    objectName: "nameField"

                    Layout.fillWidth: true
                    placeholderText: i18n.tr("My Name")
                    inputMethodHints: {
                        Qt.ImhNoPredictiveText
                        Qt.ImhSensitiveData
                    }
                }

                Label {
                    id: surnameLblForgot
                    objectName: "surnamLbl"

                    text: i18n.tr("Surname:")
                }

                TextField {
                    id: surnameFieldForgot
                    objectName: "surnameField"

                    Layout.fillWidth: true
                    placeholderText: i18n.tr("Surname:")
                    inputMethodHints: {
                        Qt.ImhNoPredictiveText
                        Qt.ImhSensitiveData
                    }
                }

                Label {
                    id: idLblForgot
                    objectName: "idLbl"

                    text: i18n.tr("ID:")
                }

                TextField {
                    id: idFieldForgot
                    objectName: "idField"

                    Layout.fillWidth: true
                    placeholderText: i18n.tr("My ID")
                    inputMethodHints: {
                        Qt.ImhNoAutoUppercase
                        Qt.ImhNoPredictiveText
                        Qt.ImhSensitiveData
                    }
                }

                Label {
                    id: birthDateLblForgot
                    objectName: "birthDateLbl"

                    text: i18n.tr("Birth date:")
                }

                DatePicker {
                    id: birthDatePickerForgot
                    objectName: "birthDatePicker"

                    Layout.fillWidth: true
                    maximum: new Date()
                    minimum: new Date("1900/01/01")
                }

                Label {
                    id: emailLblForgot
                    objectName: "emailLbl"

                    text: i18n.tr("E-Mail:")
                }

                TextField {
                    id: emailFieldForgot
                    objectName: "emailField"

                    Layout.fillWidth: true
                    placeholderText: i18n.tr("my@mail.com")
                    inputMethodHints: {
                        Qt.ImhEmailCharactersOnly
                        Qt.ImhNoAutoUppercase
                        Qt.ImhNoPredictiveText
                        Qt.ImhSensitiveData
                    }
                }
            }

            Button {
                id: submitBtnOne
                objectName: "submitBtnOne"

                x: parent.width / 2 - width / 2
                y: parent.height - height - root.spacing * 2
                text: i18n.tr("Submit")
                color: UbuntuColors.orange

                onClicked: {
                    // In case the fields are not filled, complain
                    if (!nameFieldForgot.text || !surnameLblForgot.text
                            || !idFieldForgot.text || !emailFieldForgot.text)
                            PopupUtils.open(emptyFields)
                }
            }
        }
    }

    // The shape that contains the form to change the password
    UbuntuShape {
        id: secondShape
        objectName: "secondShape"

        x: root.margins
        y: firstShape.y + firstShape.height + root.spacing
        width: parent.width - root.margins * 2
        height: (parent.height - root.margins * 2) / 2

        // The header to indicate what this is
        ListItem.Header {
            id: secondShapeHeader
            objectName: "secondShapeHeader"

            text: i18n.tr("Change my password")
        }

        // The flickable to see the whole form
        Flickable {
            id: secondShapeFlickable
            objectName: "secondShapeFlickable"

            clip: true
            width: parent.width
            height: parent.height - secondShapeHeader.height
            contentWidth: parent.width
            contentHeight: secondGrid.height + submitBtnTwo.height
                           + root.spacing * 3
            x: root.spacing
            y: root.spacing + secondShapeHeader.height

            // The grid that contains the form
            GridLayout {
                id: secondGrid
                objectName: "secondGrid"

                columnSpacing: root.spacing
                rowSpacing: root.spacing
                columns: 2
                rows: 9
                width: parent.width - root.spacing * 2

                Label {
                    id: nameLblNew
                    objectName: "nameLbl"

                    text: i18n.tr("Name:")
                }

                TextField {
                    id: nameFieldNew
                    objectName: "nameField"

                    Layout.fillWidth: true
                    placeholderText: i18n.tr("My Name")
                    inputMethodHints: {
                        Qt.ImhNoPredictiveText
                        Qt.ImhSensitiveData
                    }
                }

                Label {
                    id: surnameLblNew
                    objectName: "surnamLbl"

                    text: i18n.tr("Surname:")
                }

                TextField {
                    id: surnameFieldNew
                    objectName: "surnameField"

                    Layout.fillWidth: true
                    placeholderText: i18n.tr("Surname:")
                    inputMethodHints: {
                        Qt.ImhNoPredictiveText
                        Qt.ImhSensitiveData
                    }
                }

                Label {
                    id: idLblNew
                    objectName: "idLbl"

                    text: i18n.tr("ID:")
                }

                TextField {
                    id: idFieldNew
                    objectName: "idField"

                    Layout.fillWidth: true
                    placeholderText: i18n.tr("My ID")
                    inputMethodHints: {
                        Qt.ImhNoAutoUppercase
                        Qt.ImhNoPredictiveText
                        Qt.ImhSensitiveData
                    }
                }

                Label {
                    id: birthDateLblNew
                    objectName: "birthDateLbl"

                    text: i18n.tr("Birth date:")
                }

                DatePicker {
                    id: birthDatePickerNew
                    objectName: "birthDatePicker"

                    Layout.fillWidth: true
                    maximum: new Date()
                    minimum: new Date("1900/01/01")
                }

                Label {
                    id: emailLblNew
                    objectName: "emailLbl"

                    text: i18n.tr("E-Mail:")
                }

                TextField {
                    id: emailFieldNew
                    objectName: "emailField"

                    Layout.fillWidth: true
                    placeholderText: i18n.tr("my@mail.com")
                    inputMethodHints: {
                        Qt.ImhEmailCharactersOnly
                        Qt.ImhNoAutoUppercase
                        Qt.ImhNoPredictiveText
                        Qt.ImhSensitiveData
                    }
                }

                Label {
                    id: oldPassLbl
                    objectName: "oldPassLbl"

                    text: i18n.tr("Old password:")
                }

                TextField {
                    id: oldPassField
                    objectName: "oldPassField"

                    Layout.fillWidth: true
                    placeholderText: i18n.tr("My Old Password")
                    echoMode: TextInput.Password
                    inputMethodHints: {
                        Qt.ImhNoAutoUppercase
                        Qt.ImhNoPredictiveText
                        Qt.ImhSensitiveData
                    }
                }

                Label {
                    id: firstPassLbl
                    objectName: "firstPassLbl"

                    text: i18n.tr("New password:")
                }

                TextField {
                    id: firstPassField
                    objectName: "firstPassField"

                    Layout.fillWidth: true
                    placeholderText: i18n.tr("My Password")
                    echoMode: TextInput.Password
                    inputMethodHints: {
                        Qt.ImhNoAutoUppercase
                        Qt.ImhNoPredictiveText
                        Qt.ImhSensitiveData
                    }

                    onTextChanged: {
                        // If the passwords are not equal
                        if (text !== secondPassField.text)
                            // The text is red
                            secondPassField.color = UbuntuColors.red
                        else
                            // Back to normal
                            secondPassField.color = UbuntuColors.darkGrey
                    }
                }

                Label {
                    id: secondPassLbl
                    objectName: "secondPassLbl"

                    text: i18n.tr("Repeat password:")
                }

                TextField {
                    id: secondPassField
                    objectName: "secondPassField"

                    Layout.fillWidth: true
                    placeholderText: i18n.tr("My Password")
                    echoMode: TextInput.Password
                    inputMethodHints: {
                        Qt.ImhNoAutoUppercase
                        Qt.ImhNoPredictiveText
                        Qt.ImhSensitiveData
                    }

                    onTextChanged: {
                        // If the passwords are not equal
                        if (firstPassField.text !== text)
                            color = UbuntuColors.red // The text is red
                        else
                            color = UbuntuColors.darkGrey // Back to normal
                    }
                }

                Label {
                    id: showPassLbl
                    objectName: "showPassLbl"

                    text: i18n.tr("Show passwords:")
                }

                // Make possible showing the passwords
                CheckBox {
                    id: showPassCheckBox
                    objectName: "showPassCheckBox"

                    Layout.alignment: Layout.Center
                    text: i18n.tr("Show passwords:")

                    onCheckedChanged: {
                        if (checked)
                        {
                            oldPassField.echoMode = TextInput.Normal
                            firstPassField.echoMode = TextInput.Normal
                            secondPassField.echoMode = TextInput.Normal
                        }
                        else
                        {
                            oldPassField.echoMode = TextInput.Password
                            firstPassField.echoMode = TextInput.Password
                            secondPassField.echoMode = TextInput.Password
                        }
                    }
                }
            }

            Button {
                id: submitBtnTwo
                objectName: "submitBtnTwo"

                x: parent.width / 2 - width / 2
                y: parent.height - height - root.spacing * 2
                text: i18n.tr("Submit")
                color: UbuntuColors.orange

                onClicked: {
                    // Complain if the fields are not filled
                    if (!nameFieldNew.text || !surnameLblNew.text
                            || !idFieldNew.text || !emailFieldNew.text
                            || !oldPassField.text || !firstPassField.text
                            || !secondPassField.text)
                            PopupUtils.open(emptyFields)
                    // Complain if the passwords are not the same
                    else if (firstPassField.text !== secondPassField.text)
                        PopupUtils.open(badPasses)
                }
            }
        }
    }
}
