/*
 * Copyright (C) 2014 Víctor Matía Rodríguez.
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; version 3.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

#ifndef CHEETAHCS_H
#define CHEETAHCS_H

#include <QObject>
#include <QString>
#include <QStringList>

#include "startchecks.h"

class CheetaHCS : public QObject
{
    Q_OBJECT
    // We define the properties that are accesible through QML
    Q_PROPERTY(bool configExists READ configExists WRITE setConfigExists
               NOTIFY configExistsChanged) /* Whether the configuration file
                                            * exits or not */
    Q_PROPERTY(QString hospital READ hospital WRITE setHospital
               NOTIFY hospitalChanged) // The chosen hospital for the program
    Q_PROPERTY(QString primaryCenter READ primaryCenter WRITE setPrimaryCenter
               NOTIFY primaryCenterChanged) // The chosen primary center
    Q_PROPERTY(QStringList hospitals READ hospitals WRITE setHospitals
               NOTIFY hospitalsChanged) // The list of available hospitals
    Q_PROPERTY(QStringList primaryCenters READ primaryCenters
               WRITE setPrimaryCenters NOTIFY primaryCentersChanged)
                // The list of available primary centers
    // Public functions
public:
    explicit CheetaHCS(QObject *parent = 0); // Constructor
    virtual ~CheetaHCS();                    // Destructor

    // The invocable-from-qml functions
    Q_INVOKABLE void startChecks(); // Checks for the start and configuration
    Q_INVOKABLE void configure(int hospital, int primaryCenter); /* Create the
                                                                  * config file
                                                                  */
    Q_INVOKABLE void readConfig(); // The function to read the config file

    // The signals emited by the properties when they change
Q_SIGNALS:
    void configExistsChanged();
    void hospitalChanged();
    void primaryCenterChanged();
    void hospitalsChanged();
    void primaryCentersChanged();

    // The protected functions for the properties and variables
protected:
    bool m_configExists;
    bool configExists();
    void setConfigExists(bool configExists);

    QString m_hospital;
    QString hospital();
    void setHospital(QString hospital);

    QString m_primaryCenter;
    QString primaryCenter();
    void setPrimaryCenter(QString primaryCenter);

    QStringList m_hospitals;
    QStringList hospitals();
    void setHospitals(QStringList hospitals);

    QStringList m_primaryCenters;
    QStringList primaryCenters();
    void setPrimaryCenters(QStringList primaryCenters);

    // The private functions and variables
private:
    StartChecks startChecksFunction; // The startchecks.h into a variable

    QString m_folder; // The configuration folder
    QString m_file; // The configuration file

    void readConfiguration(QString configFile); // Read the config file
};

#endif // CHEETAHCS_H
